WalletHd class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
btcMnemonicToPrivateKey(String mnemonic, {String? derivePath})
→ String
-
-
createRandomMnemonic()
→ String
-
-
ethMnemonicToPrivateKey(String mnemonic, {String? derivePath})
→ EthPrivateKey
-
-
getAccountAddress(String mnemonic, {String? derivePath})
→ Future<Map<String, String>>
-
-
transactionBTC(String mnemonic, String fromAddress, String toAddress, String amount, num fee, List<BitcoinIn> unspand)
→ Future<String?>
-
-
transactionERC20USDT(String mnemonic, String fromAddress, String toAddress, String amount, String gasPrice, int nonce)
→ Future<String?>
-
-
transactionETH(String mnemonic, String fromAddress, String toAddress, String amount, String gasPrice, int nonce)
→ Future<String?>
-